@@ -589,6 +589,23 @@ class CoreDriver(BaseDriver):
         response = self.request('midas.item.searchbyname', parameters)
         return response['items']
 
+    def search_item_by_name_and_folder(self, name, folder_id, token=None):
+        """Return all items with a given name and parent folder id.
+
+        :param name: The name of the item to search by.
+        :param folder_id: The id of the parent folder to search by.
+        :param token: (optional) A valid token for the user in question.
+
+        :returns: A list of all items with the given name and parent folder id.
+        """
+        parameters = dict()
+        parameters['name'] = name
+        parameters['folderId'] = folder_id
+        if token:
+            parameters['token'] = token
+        response = self.request('midas.item.searchbynameandfolder', parameters)
+        return response['items']
+
     def search_item_by_name_and_folder_name(self, name, folder_name, token=None):
         """Return all items with a given name and parent folder name.
 
